@@ -5,8 +5,8 @@
 #' @param type_anova type of ANOVA test "I","II" or "III", Default:"II".
 #' @param interact_anova Logical; if TRUE calculates interaction effect,
 #' Default: TRUE.
-#' @param es_anova Type of effect size either "f" for f squared,"eta" for eta
-#' squared or "none", Default:"none".
+#' @param es_anova Type of effect size either "f2" for f squared,"eta2" for eta
+#' squared, "omega2" for omega squared or "none", Default:"none".
 #' @inheritParams t_greene
 #' @inheritParams t_test
 #' @param lower.tail Logical; if TRUE probabilities are `P[X <= x]`,
@@ -15,28 +15,45 @@
 #' different populations using \link{t_greene} Default: FALSE
 #' @param ... Additional arguments that could be passed to the \link{t_greene}
 #' function
-#' @return  ANOVA tale.
+#' @return  ANOVA table.
 #' @details Data is entered as a data frame of summary statistics where
 #' the column containing population names is chosen by position (first by
 #' default), other columns of summary data should have specific names (case
 #' sensitive) similar to \link{baboon.parms_df}
 #' @examples
-#' # Comparisons of femur head diameter in four populations
-#' library(TestDimorph)
-#' df <-
-#'   data.frame(
-#'     Pop = c("Turkish", "Bulgarian", "Greek", "Portuguese "),
-#'     m = c(150.00, 82.00, 36.00, 34.00),
-#'     M.mu = c(49.39, 48.33, 46.99, 45.20),
-#'     M.sdev = c(3.01, 2.53, 2.47, 2.00),
-#'     f = c(150.00, 58.00, 34.00, 24.00),
-#'     F.mu = c(42.91, 42.89, 42.44, 40.90),
-#'     F.sdev = c(2.90, 2.84, 2.26, 2.90)
-#'   )
-#' univariate(df, pairwise = TRUE, padjust = "bonferroni")
+#' #'
+#' # See Tables 6 and 8 and from Fidler and Thompson (2001).
+#' # The “eta2” and “omega2” CIs match those in Table 8.
+#' # See “FT” dataset for Fidler and Thompson (2001) reference
+#'
+#' # acquiring summary data
+#' FT_sum <- extract_sum(FT, test = "uni", run = FALSE)
+#' # univariate analysis on summary data
+#' univariate(FT_sum, CI = 0.90, es_anova = "eta2", digits = 5)
+#' univariate(FT_sum, CI = 0.90, es_anova = "omega2", digits = 5)
+#'
+#'
+#' # Reproduces Table 2 from Shaw and Mitchell-Olds (1993) using their Table 1.
+#' # See “SMO” dataset for Shaw and Mitchell-Olds (1993) reference
+#' # Note that Table 2 residual df is incorrectly given as 6,
+#' # but is correctly given as 7 in Hector et al. (2010)
+#'
+#' # acquiring summary data
+#' univ_SMO <- extract_sum(SMO, test = "uni", run = FALSE)
+#' # univariate analysis on summary data
+#' print(univariate(univ_SMO, type_anova = "I")[[1]])
+#' print(univariate(univ_SMO, type_anova = "II"))
+#' univariate(univ_SMO, type_anova = "III")
+#'
 #' @rdname univariate
 #' @export
 #' @importFrom stats pf
+#' @references
+#'
+#'   Hector, Andy, Stefanie Von Felten, and Bernhard Schmid. "Analysis of variance
+#'   with unbalanced data: an update for ecology & evolution." Journal of animal
+#'   ecology 79.2 (2010): 308-316.
+#'
 univariate <- function(x,
                        Pop = 1,
                        type_anova = "II",
@@ -47,11 +64,10 @@ univariate <- function(x,
                        ...,
                        lower.tail = FALSE,
                        CI = 0.95,
-                       N = NULL,
                        digits = 4) {
   padjust <- match.arg(padjust, choices = p.adjust.methods)
   es_anova <-
-    match.arg(es_anova, choices = c("none", "eta", "f"))
+    match.arg(es_anova, choices = c("none", "eta2", "f2", "omega2"))
 
   if (!(is.data.frame(x))) {
     stop("x should be a dataframe")
@@ -99,13 +115,11 @@ univariate <- function(x,
       I = anova_main_I(
         x,
         es_anova,
-
         digits, CI, lower.tail
       ),
       II = anova_main_II(
         x,
         es_anova,
-
         digits, CI, lower.tail
       )
     )
@@ -114,7 +128,6 @@ univariate <- function(x,
       I = anova_I(
         x,
         es_anova,
-
         digits, CI, lower.tail
       ),
       II = anova_II(
@@ -125,15 +138,11 @@ univariate <- function(x,
       III = anova_III(
         x,
         es_anova,
-
         digits, CI, lower.tail
       )
     )
   }
 
-
-
-
   if (isTRUE(pairwise)) {
     out <-
       list(
@@ -142,6 +151,7 @@ univariate <- function(x,
           x,
           Pop = Pop,
           padjust = padjust,
+          CI = CI,
           ...
         )
       )
